summary refs log tree commit diff
diff options
context:
space:
mode:
authorPatrick Cloke <clokep@users.noreply.github.com>2023-01-25 16:45:01 -0500
committerDavid Robertson <davidr@element.io>2023-01-26 10:43:57 +0000
commit1ce0bd2d7785f06b923a150755e9a1863d20eeb9 (patch)
treed4bf6ff283a5abec766837e9338152b2077ed94a
parentApply suggestions from code review (diff)
downloadsynapse-1ce0bd2d7785f06b923a150755e9a1863d20eeb9.tar.xz
Clarify comments.
Co-authored-by: Sean Quah <8349537+squahtx@users.noreply.github.com>
-rw-r--r--synapse/storage/databases/main/room.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/synapse/storage/databases/main/room.py b/synapse/storage/databases/main/room.py
index 534baab7c8..c28eced8d9 100644
--- a/synapse/storage/databases/main/room.py
+++ b/synapse/storage/databases/main/room.py
@@ -1278,9 +1278,9 @@ class RoomWorkerStore(CacheInvalidationWorkerStore):
     async def is_partial_state_rooms(
         self, room_ids: StrCollection
     ) -> Mapping[str, bool]:
         """Checks if this room has partial state.
 
-        Returns true if this is a "partial-state" room, which means that the state
+        Returns true for "partial-state" rooms, which means that the state
         at events in the room, and `current_state_events`, may not yet be
         complete.
         """
@@ -1278,9 +1278,9 @@ class RoomWorkerStore(CacheInvalidationWorkerStore):
         self, room_ids: StrCollection
     ) -> Mapping[str, bool]:
-        """Checks if this room has partial state.
+        """Checks if the given rooms have partial state.
 